@@ -19,8 +19,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef __AV_META_READER
-#define __AV_META_READER
+#ifndef _AV_META_READER_H
+#define _AV_META_READER_H
 
 #include <libdmapsharing/dmap.h>
 
@@ -62,6 +62,6 @@ gboolean av_meta_reader_read (AVMetaReader    *reader,
 
 GOptionGroup *av_meta_reader_get_option_group (AVMetaReader *reader);
 
-#endif /* __AV_META_READER */
-
 G_END_DECLS
+
+#endif
