@@ -24,7 +24,7 @@
 #include "av-render-gst.h"
 #include "util-gst.h"
 
-const GstClockTime TRANSITION_TIMEOUT = 1 * GST_SECOND;
+static const GstClockTime _TRANSITION_TIMEOUT = 1 * GST_SECOND;
 
 struct AVRenderGstPrivate {
 	GMainLoop *loop;
@@ -73,7 +73,7 @@ av_render_gst_now_playing_record (DmapControlPlayer * player)
 	return fnval;
 }
 
-guchar *
+gchar *
 av_render_gst_now_playing_artwork (DmapControlPlayer * player, guint width,
 				 guint height)
 {
@@ -84,8 +84,8 @@ av_render_gst_now_playing_artwork (DmapControlPlayer * player, guint width,
 void
 av_render_gst_pause (DmapControlPlayer * player)
 {
-	transition_pipeline (AV_RENDER_GST (player)->priv->pipeline, GST_STATE_PAUSED, TRANSITION_TIMEOUT);
-	AV_RENDER_GST (player)->priv->play_state = CONTROL_PLAY_PAUSED;
+	util_gst_transition_pipeline (AV_RENDER_GST (player)->priv->pipeline, GST_STATE_PAUSED, _TRANSITION_TIMEOUT);
+	AV_RENDER_GST (player)->priv->play_state = DMAP_CONTROL_PLAY_PAUSED;
 }
 
 void
@@ -95,11 +95,11 @@ av_render_gst_play_pause (DmapControlPlayer * player)
 
 	if (render->priv->pipeline) {
 		GstState state;
-		GstStateChangeReturn ret = gst_element_get_state (render->priv->pipeline, &state, NULL, TRANSITION_TIMEOUT);
+		GstStateChangeReturn ret = gst_element_get_state (render->priv->pipeline, &state, NULL, _TRANSITION_TIMEOUT);
 		if (ret == GST_STATE_CHANGE_SUCCESS) {
 			if (state == GST_STATE_PAUSED) {
-				transition_pipeline (render->priv->pipeline, GST_STATE_PLAYING, TRANSITION_TIMEOUT);
-				render->priv->play_state = CONTROL_PLAY_PLAYING;
+				util_gst_transition_pipeline (render->priv->pipeline, GST_STATE_PLAYING, _TRANSITION_TIMEOUT);
+				render->priv->play_state = DMAP_CONTROL_PLAY_PLAYING;
 			} else {
 				av_render_gst_pause (player);
 			}
@@ -108,20 +108,21 @@ av_render_gst_play_pause (DmapControlPlayer * player)
 }
 
 // FIXME EOS handler goes to next song; should this be more explicit here?
-void play_list_starting_at_current (AVRenderGst *render)
+static void
+_play_list_starting_at_current (AVRenderGst *render)
 {
 	gchar *location = NULL;
 
-	transition_pipeline (render->priv->pipeline, GST_STATE_READY, TRANSITION_TIMEOUT);
-	render->priv->play_state = CONTROL_PLAY_STOPPED;
+	util_gst_transition_pipeline (render->priv->pipeline, GST_STATE_READY, _TRANSITION_TIMEOUT);
+	render->priv->play_state = DMAP_CONTROL_PLAY_STOPPED;
 
 	g_object_get (render->priv->song_current->data, "location", &location, NULL);
 	g_object_set (G_OBJECT (render->priv->src_decoder), "uri", location, NULL);
 
 	g_debug ("Playing %s", location);
 
-	transition_pipeline (render->priv->pipeline, GST_STATE_PLAYING, TRANSITION_TIMEOUT);
-	render->priv->play_state = CONTROL_PLAY_PLAYING;
+	util_gst_transition_pipeline (render->priv->pipeline, GST_STATE_PLAYING, _TRANSITION_TIMEOUT);
+	render->priv->play_state = DMAP_CONTROL_PLAY_PLAYING;
 
 	g_free(location);
 }
@@ -132,16 +133,17 @@ av_render_gst_next_item (DmapControlPlayer * player)
 	AVRenderGst *render = AV_RENDER_GST (player);
 
 	render->priv->song_current = render->priv->song_current->next;
-	play_list_starting_at_current (render);
+	_play_list_starting_at_current (render);
 }
 
-void
-av_render_gst_prev_item (DmapControlPlayer * player)
+static void
+_prev_item (DmapControlPlayer * player)
 {
 	g_warning ("Previous item not implemented");
 }
 
-static void av_render_gst_reset (AVRenderGst *render)
+static void
+_reset (AVRenderGst *render)
 {
         render->priv->pipeline    = NULL;
 	render->priv->src_decoder = NULL;
@@ -163,16 +165,16 @@ av_render_gst_cue_clear (DmapControlPlayer * player)
 
 	if (render->priv->pipeline) {
 		g_idle_add ((GSourceFunc) g_main_loop_quit, render->priv->loop);
-		transition_pipeline (render->priv->pipeline, GST_STATE_NULL, TRANSITION_TIMEOUT);
-		render->priv->play_state = CONTROL_PLAY_STOPPED;
+		util_gst_transition_pipeline (render->priv->pipeline, GST_STATE_NULL, _TRANSITION_TIMEOUT);
+		render->priv->play_state = DMAP_CONTROL_PLAY_STOPPED;
 		gst_object_unref (render->priv->pipeline);
-		av_render_gst_reset (render);
+		_reset (render);
 	}
 }
 
 /* FIXME: mostly copied from AVReadMetaGst */
 static void
-pad_added_cb (GstElement *decodebin, GstPad *pad,
+_pad_added_cb (GstElement *decodebin, GstPad *pad,
               AVRenderGstPrivate *priv)
 {
         GstCaps *caps;
@@ -198,7 +200,7 @@ pad_added_cb (GstElement *decodebin, GstPad *pad,
                 sink_pad = gst_element_get_static_pad (priv->resample, "sink");
                 g_assert (sink_pad != NULL);
 
-                if (pads_compatible (pad, sink_pad)) {
+                if (util_gst_pads_compatible (pad, sink_pad)) {
                         g_assert (! GST_PAD_IS_LINKED (sink_pad));
                         gst_pad_link (pad, sink_pad);
                 }
@@ -209,13 +211,14 @@ _return:
 	gst_caps_unref (caps);
 }
 
-gboolean bus_cb (GstBus *bus, GstMessage *message, AVRenderGst *render)
+static gboolean
+_bus_cb (GstBus *bus, GstMessage *message, AVRenderGst *render)
 {
 	switch (message->type) {
 	case GST_MESSAGE_ERROR:
 		g_warning ("GStreamer error message");
-		transition_pipeline (render->priv->pipeline, GST_STATE_READY, TRANSITION_TIMEOUT);
-		render->priv->play_state = CONTROL_PLAY_STOPPED;
+		util_gst_transition_pipeline (render->priv->pipeline, GST_STATE_READY, _TRANSITION_TIMEOUT);
+		render->priv->play_state = DMAP_CONTROL_PLAY_STOPPED;
 		g_idle_add ((GSourceFunc) g_main_loop_quit, render->priv->loop);
 		break;
 	case GST_MESSAGE_EOS:
@@ -237,7 +240,7 @@ gboolean bus_cb (GstBus *bus, GstMessage *message, AVRenderGst *render)
  * and audioconvert.
  */
 static GstElement *
-setup_pipeline (const char *sinkname)
+_setup_pipeline (const char *sinkname)
 {
 	GstElement *pipeline, *src_decoder, *resample, *convert, *sink;
 
@@ -272,21 +275,33 @@ setup_pipeline (const char *sinkname)
 	}
 
 	g_debug ("    Created a pipeline.");
-	return pipeline;
+
+	goto done;
 
 _error:
-	if (src_decoder != NULL)
+	if (src_decoder != NULL) {
 		g_object_unref (src_decoder);
-	if (resample != NULL)
-		g_object_unref (resample);
-	if (convert != NULL)
-		g_object_unref (convert);
-	if (sink != NULL)
-		g_object_unref (sink);
-	if (pipeline != NULL)
-		g_object_unref (pipeline);
+	}
 
-	return NULL;
+	if (resample != NULL) {
+		g_object_unref (resample);
+	}
+
+	if (convert != NULL) {
+		g_object_unref (convert);
+	}
+
+	if (sink != NULL) {
+		g_object_unref (sink);
+	}
+
+	if (pipeline != NULL) {
+		g_object_unref (pipeline);
+		pipeline = NULL;
+	}
+
+done:
+	return pipeline;
 }
 
 void
@@ -294,8 +309,9 @@ av_render_gst_cue_play (DmapControlPlayer * player, GList * records, guint index
 {
 	AVRenderGst *render = AV_RENDER_GST (player);
 
-	if (! (render->priv->pipeline = setup_pipeline ("apexsink")))
+	if (! (render->priv->pipeline = _setup_pipeline ("apexsink"))) {
 		goto _return;
+	}
 
 	render->priv->src_decoder      = gst_bin_get_by_name (GST_BIN (render->priv->pipeline), "src-decoder");
 	render->priv->resample = gst_bin_get_by_name (GST_BIN (render->priv->pipeline), "resample");
@@ -305,15 +321,16 @@ av_render_gst_cue_play (DmapControlPlayer * player, GList * records, guint index
 	if (render->priv->src_decoder == NULL
 	 || render->priv->resample == NULL
 	 || render->priv->sink == NULL
-         || bus == NULL)
+         || bus == NULL) {
 		goto _return;
+	}
 
 	g_signal_connect (render->priv->src_decoder,
                           "pad-added",
-                          G_CALLBACK (pad_added_cb),
+                          G_CALLBACK (_pad_added_cb),
                           render->priv);
 
-	gst_bus_add_watch (bus, (GstBusFunc) bus_cb, render);
+	gst_bus_add_watch (bus, (GstBusFunc) _bus_cb, render);
 		
 	if (render->priv->host) {
 		g_object_set (G_OBJECT (render->priv->sink), "host", render->priv->host, NULL);
@@ -329,26 +346,24 @@ av_render_gst_cue_play (DmapControlPlayer * player, GList * records, guint index
 	render->priv->song_list = records;
 	render->priv->song_current = g_list_nth (records, index);
 
-	play_list_starting_at_current (render);
+	_play_list_starting_at_current (render);
 
 	g_main_loop_run (render->priv->loop);
 
-	if (transition_pipeline (render->priv->pipeline, GST_STATE_NULL, TRANSITION_TIMEOUT) == FALSE)
+	if (util_gst_transition_pipeline (render->priv->pipeline, GST_STATE_NULL, _TRANSITION_TIMEOUT) == FALSE) {
 		goto _return;
-	render->priv->play_state = CONTROL_PLAY_STOPPED;
+	}
+	render->priv->play_state = DMAP_CONTROL_PLAY_STOPPED;
 
 _return:
 	gst_object_unref (render->priv->pipeline);
-	av_render_gst_reset (render);
+	_reset (render);
 }
 
-GOptionGroup *av_render_gst_get_option_group (AVRender *render)
+GOptionGroup *
+av_render_gst_get_option_group (AVRender *render)
 {
-	if (gst_is_initialized ()) {
-		return NULL;
-	} else {
-		return gst_init_get_option_group ();
-	}
+	return gst_is_initialized () ? NULL : gst_init_get_option_group ();
 }
 
 static void av_render_gst_register_type (GTypeModule *module);
@@ -380,14 +395,14 @@ av_render_gst_init (AVRenderGst *render)
 	render->priv->transport_protocol = DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL_TCP;
 
 	render->priv->shuffle_state = FALSE;
-	render->priv->repeat_state  = CONTROL_REPEAT_NONE;
-	render->priv->play_state    = CONTROL_PLAY_STOPPED;
+	render->priv->repeat_state  = DMAP_CONTROL_REPEAT_NONE;
+	render->priv->play_state    = DMAP_CONTROL_PLAY_STOPPED;
 
-	av_render_gst_reset (render);
+	_reset (render);
 }
 
 static void
-av_render_gst_finalize (GObject *self)
+_finalize (GObject *self)
 {
 }
 
@@ -397,10 +412,7 @@ av_render_gst_class_finalize (AVRenderGstClass *klass)
 }
 
 static void
-av_render_gst_get_property (GObject *object,
-                        guint prop_id,
-                        GValue *value,
-                        GParamSpec *pspec)
+_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
 	AVRenderGst *render = AV_RENDER_GST (object);
 
@@ -444,10 +456,10 @@ av_render_gst_get_property (GObject *object,
 }
 
 static void
-av_render_gst_set_property (GObject *object,
-                        guint prop_id,
-                        const GValue *value,
-                        GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
 	AVRenderGst *render = AV_RENDER_GST (object);
 
@@ -497,16 +509,16 @@ av_render_gst_class_init (AVRenderGstClass *klass)
 
 	g_type_class_add_private (klass, sizeof (AVRenderGstPrivate));
 
-	gobject_class->set_property = av_render_gst_set_property;
-	gobject_class->get_property = av_render_gst_get_property;
-	gobject_class->finalize = av_render_gst_finalize;
+	gobject_class->set_property = _set_property;
+	gobject_class->get_property = _get_property;
+	gobject_class->finalize = _finalize;
 
 	av_render_class->now_playing_record = av_render_gst_now_playing_record;
 	av_render_class->now_playing_artwork = av_render_gst_now_playing_artwork;
 	av_render_class->play_pause = av_render_gst_play_pause;
 	av_render_class->pause = av_render_gst_pause;
 	av_render_class->next_item = av_render_gst_next_item;
-	av_render_class->prev_item = av_render_gst_prev_item;
+	av_render_class->prev_item = _prev_item;
 	av_render_class->cue_clear = av_render_gst_cue_clear;
 	av_render_class->cue_play = av_render_gst_cue_play;
 	av_render_class->get_option_group = av_render_gst_get_option_group;
@@ -545,6 +557,4 @@ av_render_gst_class_init (AVRenderGstClass *klass)
 							    G_PARAM_READWRITE));
 }
 
-G_DEFINE_DYNAMIC_TYPE (AVRenderGst,
-                       av_render_gst,
-                       TYPE_AV_RENDER)
+G_DEFINE_DYNAMIC_TYPE (AVRenderGst, av_render_gst, TYPE_AV_RENDER)
