@@ -36,10 +36,10 @@ enum {
 };
 
 static void
-db_builder_gdir_set_property (GObject *object,
-                              guint prop_id,
-                              const GValue *value,
-                              GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
 	DbBuilderGDir *builder = DB_BUILDER_GDIR (object);
 
@@ -63,10 +63,7 @@ db_builder_gdir_set_property (GObject *object,
 }
 
 static void
-db_builder_gdir_get_property (GObject *object,
-                                 guint prop_id,
-                                 GValue *value,
-                                 GParamSpec *pspec)
+_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
 	DbBuilderGDir *builder = DB_BUILDER_GDIR (object);
 
@@ -83,19 +80,22 @@ db_builder_gdir_get_property (GObject *object,
 	}
 }
 
-static void
-db_builder_gdir_build_db_starting_at (DbBuilder *builder, 
-				      const char *dir,
-				      DmapContainerRecord *container_record);
+static gboolean
+_build_db_starting_at(DbBuilder *builder,
+                      const char *dir,
+                      DmapContainerRecord *container_record,
+                      GError **error);
 
 static void
-db_builder_gdir_monitor_directory (DbBuilderGDir *builder, const char *path);
+_monitor_directory (DbBuilderGDir *builder, const char *path);
 
-static void
-db_builder_gdir_handle_path (DbBuilderGDir *builder,
-                             const char *path,
-                             DmapContainerRecord *container_record)
+static gboolean
+_handle_path(DbBuilderGDir *builder,
+             const char *path,
+             DmapContainerRecord *container_record,
+             GError **error)
 {
+	gboolean ok = FALSE;
 	gchar *filename = g_path_get_basename (path);
 
 	if (g_file_test (path, G_FILE_TEST_IS_DIR)) {
@@ -103,17 +103,24 @@ db_builder_gdir_handle_path (DbBuilderGDir *builder,
 		                                                                  "name", filename,
 		                                                                  "full-db", builder->priv->db,
 		                                                                   NULL));
-		db_builder_gdir_build_db_starting_at (DB_BUILDER (builder), path, record);
+		ok = _build_db_starting_at(DB_BUILDER (builder),
+		                           path,
+		                           record,
+		                           error);
+		if (!ok) {
+			goto done;
+		}
+
 		if (NULL != builder->priv->container_db) {
 			if (dmap_container_record_get_entry_count (record) > 0) {
-				dmap_container_db_add (builder->priv->container_db, record);
+				dmap_container_db_add (builder->priv->container_db, record, NULL);
 			} else {
 				g_warning ("Container %s is empty, skipping", path);
 			}
 		}
 		g_object_unref (record);
 
-		db_builder_gdir_monitor_directory (DB_BUILDER_GDIR (builder), path);
+		_monitor_directory (DB_BUILDER_GDIR (builder), path);
 	} else {
 		gchar *location;
 		guint id = 0;
@@ -124,26 +131,32 @@ db_builder_gdir_handle_path (DbBuilderGDir *builder,
 		g_free (location);
 
 		if (! id) {
-			id = dmap_db_add_path (builder->priv->db, path);
+			id = dmap_db_add_path (builder->priv->db, path, error);
+			if (!id) {
+				goto done;
+			}
 			g_debug ("Done processing %s with id. %u (record #%lu).", path, id, dmap_db_count (builder->priv->db));
 		} else {
 			g_debug ("Done processing (cached) %s with id. %u (record #%lu).", path, id, dmap_db_count (builder->priv->db));
 		}
 
-		if (id) {
-			if (container_record) {
-				dmap_container_record_add_entry (container_record, NULL, id);
-			}
-		} else {
-			g_debug ("Skipped %s", path);
+		if (container_record) {
+			dmap_container_record_add_entry (container_record, NULL, id, NULL);
 		}
 	}
 
+done:
 	g_free (filename);
+
+	return ok;
 }
 
 static void
-db_builder_gdir_file_changed_cb (GFileMonitor *monitor, GFile *file, GFile *other_file, GFileMonitorEvent event_type, DbBuilderGDir *builder)
+_file_changed_cb (GFileMonitor *monitor,
+                  GFile *file,
+                  GFile *other_file,
+                  GFileMonitorEvent event_type,
+                  DbBuilderGDir *builder)
 {
 	g_assert (G_IS_FILE_MONITOR (monitor));
 	g_assert (G_IS_FILE (file));
@@ -151,6 +164,9 @@ db_builder_gdir_file_changed_cb (GFileMonitor *monitor, GFile *file, GFile *othe
 
 	// FIXME: Need to lock database?
 
+	gboolean ok;
+	GError *error = NULL;
+
 	gchar *path = g_file_get_path (file);
 	if (NULL == path) {
 		g_warning ("Could not determine path for changed file\n");
@@ -160,7 +176,13 @@ db_builder_gdir_file_changed_cb (GFileMonitor *monitor, GFile *file, GFile *othe
 	switch (event_type) {
 		case G_FILE_MONITOR_EVENT_CREATED:
 			g_debug ("New file: %s\n", path);
-			db_builder_gdir_handle_path (builder, path, NULL);
+
+			ok = _handle_path (builder, path, NULL, &error);
+			if (!ok) {
+				g_warning("Error handling new file: %s", error->message);
+				goto done;
+			}
+
 			break;
 		case G_FILE_MONITOR_EVENT_DELETED:
 			// FIXME: Not implemented, need remove function in database.
@@ -181,7 +203,7 @@ done:
 }
 
 static void
-db_builder_gdir_monitor_directory (DbBuilderGDir *builder, const char *path)
+_monitor_directory (DbBuilderGDir *builder, const char *path)
 {
 	g_assert (IS_DB_BUILDER_GDIR (builder));
 	g_assert (NULL != path);
@@ -203,7 +225,7 @@ db_builder_gdir_monitor_directory (DbBuilderGDir *builder, const char *path)
 	g_debug ("Monitoring %s\n", file);
 	g_free (file);
 
-        g_signal_connect (monitor, "changed", (GCallback) db_builder_gdir_file_changed_cb, builder);	
+        g_signal_connect (monitor, "changed", (GCallback) _file_changed_cb, builder);	
 
         builder->priv->monitor_list = g_slist_append (builder->priv->monitor_list, monitor);
 
@@ -215,31 +237,47 @@ done:
 	return;
 }
 
-static void
-db_builder_gdir_build_db_starting_at (DbBuilder *builder, 
-				      const char *dir,
-				      DmapContainerRecord *container_record)
+static gboolean
+_build_db_starting_at(DbBuilder *builder,
+                      const char *dir,
+                      DmapContainerRecord *container_record,
+                      GError **error)
 {
 	g_assert (IS_DB_BUILDER_GDIR (builder));
 
-	GError *error = NULL;
+	GDir *d;
+	gboolean ok = TRUE;
+	const gchar *entry;
 
-	GDir *d = g_dir_open (dir, 0, &error);
+	d = g_dir_open (dir, 0, error);
+	if (NULL == d) {
+		ok = FALSE;
+		goto done;
+	}
 
-	if (error != NULL) {
-		g_warning ("%s", error->message);
-	} else {
-		const gchar *entry;
-		while ((entry = g_dir_read_name (d))) {
-			gchar *path = g_strdup_printf ("%s/%s", dir, entry);
-			db_builder_gdir_handle_path (DB_BUILDER_GDIR (builder), path, container_record);
-			g_free (path);
+	while ((entry = g_dir_read_name (d))) {
+		gchar *path = g_strdup_printf ("%s/%s", dir, entry);
+
+		ok = _handle_path (DB_BUILDER_GDIR (builder),
+		                   path,
+		                   container_record,
+		                   error);
+
+		g_free (path);
+
+		if (!ok) {
+			goto done;
 		}
+	}
 
-		db_builder_gdir_monitor_directory (DB_BUILDER_GDIR (builder), dir);
-		
+	_monitor_directory (DB_BUILDER_GDIR (builder), dir);
+
+done:
+	if (NULL != d) {
 		g_dir_close (d);
 	}
+
+	return ok;
 }
 
 static void
@@ -258,7 +296,7 @@ db_builder_gdir_class_finalize (DbBuilderGDirClass *class)
 }
 
 static void
-db_builder_gdir_finalize (GObject *object)
+_finalize (GObject *object)
 {
 	g_debug ("Finalizing DbBuilderGDir");
 
@@ -274,11 +312,11 @@ static void db_builder_gdir_class_init (DbBuilderGDirClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	DbBuilderClass *db_builder_class = DB_BUILDER_CLASS (klass);
 
-        object_class->set_property = db_builder_gdir_set_property;
-        object_class->get_property = db_builder_gdir_get_property;
-        object_class->finalize     = db_builder_gdir_finalize;
+        object_class->set_property = _set_property;
+        object_class->get_property = _get_property;
+        object_class->finalize     = _finalize;
 
-	db_builder_class->build_db_starting_at = db_builder_gdir_build_db_starting_at;
+	db_builder_class->build_db_starting_at = _build_db_starting_at;
 
 	g_object_class_install_property (object_class,
                                          PROP_DB,
@@ -313,6 +351,4 @@ dmapd_module_unload (GTypeModule *module)
 {
 }
 
-G_DEFINE_DYNAMIC_TYPE (DbBuilderGDir,
-                      db_builder_gdir,
-                      TYPE_DB_BUILDER)
+G_DEFINE_DYNAMIC_TYPE (DbBuilderGDir, db_builder_gdir, TYPE_DB_BUILDER)
