@@ -22,7 +22,7 @@
 #include "dmapd-daap-record.h"
 #include "av-meta-reader.h"
 
-static DmapdDmapAvRecordFactory *factory_singleton;
+static DmapdDmapAvRecordFactory *_factory_singleton;
 
 struct DmapdDmapAvRecordFactoryPrivate {
 	AVMetaReader *av_meta_reader;
@@ -34,17 +34,18 @@ enum {
 };
 
 static void
-dmapd_daap_record_factory_set_property (GObject *object,
-					guint prop_id,
-					const GValue *value,
-					GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
-	DmapdDmapAvRecordFactory *factory = DMAPD_DMAP_AV_RECORD_FACTORY (object);
+	DmapdDmapAvRecordFactory *factory = DMAPD_DMAP_RECORD_FACTORY (object);
 
 	switch (prop_id) {
 		case PROP_META_READER:
-			if (factory->priv->av_meta_reader)
+			if (factory->priv->av_meta_reader) {
 				g_object_unref (factory->priv->av_meta_reader);
+			}
 			factory->priv->av_meta_reader = AV_META_READER (g_value_get_pointer (value));
 			break;
 		default:
@@ -54,12 +55,9 @@ dmapd_daap_record_factory_set_property (GObject *object,
 }
 
 static void
-dmapd_daap_record_factory_get_property (GObject *object,
-					guint prop_id,
-					GValue *value,
-					GParamSpec *pspec)
+_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
-	DmapdDmapAvRecordFactory *factory = DMAPD_DMAP_AV_RECORD_FACTORY (object);
+	DmapdDmapAvRecordFactory *factory = DMAPD_DMAP_RECORD_FACTORY (object);
 
 	switch (prop_id) {
 		case PROP_META_READER:
@@ -72,30 +70,32 @@ dmapd_daap_record_factory_get_property (GObject *object,
 }
 
 DmapRecord *
-dmapd_daap_record_factory_create  (DmapRecordFactory *factory,
-				   gpointer user_data)
+dmapd_daap_record_factory_create(DmapRecordFactory *factory,
+                                 gpointer user_data,
+                                 GError **error)
 {
-	return DMAP_RECORD (dmapd_daap_record_new ((const char *) user_data, DMAPD_DMAP_AV_RECORD_FACTORY (factory)->priv->av_meta_reader));
+	return DMAP_RECORD (dmapd_daap_record_new ((const char *) user_data, DMAPD_DMAP_RECORD_FACTORY (factory)->priv->av_meta_reader));
 }
 
-static GObject *dmapd_daap_record_factory_constructor (GType type,
-			       guint n_construct_properties,
-			       GObjectConstructParam *construct_properties)
+static GObject *
+_constructor (GType type,
+              guint n_construct_properties,
+              GObjectConstructParam *construct_properties)
 {
 	GObject *object;
 
-	if (! factory_singleton) {
+	if (! _factory_singleton) {
 		DmapdDmapAvRecordFactoryClass *klass;
 		GObjectClass *parent_class;
-		klass = DMAPD_DMAP_AV_RECORD_FACTORY_CLASS (
-				g_type_class_peek (TYPE_DMAPD_DMAP_AV_RECORD_FACTORY));
+		klass = DMAPD_DMAP_RECORD_FACTORY_CLASS (
+				g_type_class_peek (TYPE_DMAPD_DMAP_RECORD_FACTORY));
 		parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 		object = G_OBJECT_CLASS (parent_class)->constructor (type,
 							n_construct_properties,
 							construct_properties);
-		factory_singleton = DMAPD_DMAP_AV_RECORD_FACTORY (object);
+		_factory_singleton = DMAPD_DMAP_RECORD_FACTORY (object);
 	} else {
-		object = g_object_ref (G_OBJECT (factory_singleton));
+		object = g_object_ref (G_OBJECT (_factory_singleton));
 	}
 
 	return object;
@@ -104,7 +104,7 @@ static GObject *dmapd_daap_record_factory_constructor (GType type,
 static void
 dmapd_daap_record_factory_init (DmapdDmapAvRecordFactory *factory)
 {
-	factory->priv = DMAPD_DMAP_AV_RECORD_FACTORY_GET_PRIVATE (factory);
+	factory->priv = DMAPD_DMAP_RECORD_FACTORY_GET_PRIVATE (factory);
 }
 
 static void
@@ -114,9 +114,9 @@ dmapd_daap_record_factory_class_init (DmapdDmapAvRecordFactoryClass *klass)
 
 	g_type_class_add_private (klass, sizeof (DmapdDmapAvRecordFactoryPrivate));
 
-        gobject_class->set_property = dmapd_daap_record_factory_set_property;
-	gobject_class->get_property = dmapd_daap_record_factory_get_property;
-	gobject_class->constructor  = dmapd_daap_record_factory_constructor;
+        gobject_class->set_property = _set_property;
+	gobject_class->get_property = _get_property;
+	gobject_class->constructor  = _constructor;
 
 	g_object_class_install_property (gobject_class, PROP_META_READER,
 					 g_param_spec_pointer ("meta-reader",
@@ -127,7 +127,7 @@ dmapd_daap_record_factory_class_init (DmapdDmapAvRecordFactoryClass *klass)
 }
 
 static void
-dmapd_daap_record_factory_interface_init (gpointer iface, gpointer data)
+_dmap_record_factory_interface_init (gpointer iface, gpointer data)
 {
 	DmapRecordFactoryInterface *factory = iface;
 
@@ -138,4 +138,4 @@ dmapd_daap_record_factory_interface_init (gpointer iface, gpointer data)
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapAvRecordFactory, dmapd_daap_record_factory, G_TYPE_OBJECT, 
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD_FACTORY,
-					        dmapd_daap_record_factory_interface_init))
+					        _dmap_record_factory_interface_init))
