@@ -29,7 +29,7 @@
 #include "av-meta-reader.h"
 #include "util.h"
 
-static const char *unknown = "Unknown";
+static const char *_unknown = "Unknown";
 
 struct DmapdDmapAvRecordPrivate {
 	char *location;
@@ -79,10 +79,10 @@ enum {
 };
 
 static void
-dmapd_daap_record_set_property (GObject *object,
-				guint prop_id,
-				const GValue *value,
-				GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
 	DmapdDmapAvRecord *record = DMAPD_DMAP_AV_RECORD (object);
 
@@ -103,30 +103,30 @@ dmapd_daap_record_set_property (GObject *object,
 			record->priv->title = g_value_dup_string (value);
 			break;
 		case PROP_ALBUM:
-			stringleton_unref (record->priv->album);
-			record->priv->album = stringleton_ref (g_value_get_string(value));
+			util_stringleton_unref (record->priv->album);
+			record->priv->album = util_stringleton_ref (g_value_get_string(value));
 			break;
 		case PROP_SORT_ALBUM:
 			str = g_value_get_string(value);
-			stringleton_unref (record->priv->sort_album);
-			record->priv->sort_album = str ? stringleton_ref (str) : NULL;
+			util_stringleton_unref (record->priv->sort_album);
+			record->priv->sort_album = str ? util_stringleton_ref (str) : NULL;
 			break;
 		case PROP_ARTIST:
-			stringleton_unref (record->priv->artist);
-			record->priv->artist = stringleton_ref (g_value_get_string(value));
+			util_stringleton_unref (record->priv->artist);
+			record->priv->artist = util_stringleton_ref (g_value_get_string(value));
 			break;
 		case PROP_SORT_ARTIST:
 			str = g_value_get_string(value);
-			stringleton_unref (record->priv->sort_artist);
-			record->priv->sort_artist = str ? stringleton_ref (str) : NULL;
+			util_stringleton_unref (record->priv->sort_artist);
+			record->priv->sort_artist = str ? util_stringleton_ref (str) : NULL;
 			break;
 		case PROP_GENRE:
-			stringleton_unref (record->priv->genre);
-			record->priv->genre = stringleton_ref (g_value_get_string(value));
+			util_stringleton_unref (record->priv->genre);
+			record->priv->genre = util_stringleton_ref (g_value_get_string(value));
 			break;
 		case PROP_FORMAT:
-			stringleton_unref (record->priv->format);
-			record->priv->format = stringleton_ref (g_value_get_string(value));
+			util_stringleton_unref (record->priv->format);
+			record->priv->format = util_stringleton_ref (g_value_get_string(value));
 			break;
 		case PROP_MEDIAKIND:
 			record->priv->mediakind = g_value_get_enum (value);
@@ -170,10 +170,10 @@ dmapd_daap_record_set_property (GObject *object,
 }
 
 static void
-dmapd_daap_record_get_property (GObject *object,
-				guint prop_id,
-				GValue *value,
-				GParamSpec *pspec)
+_get_property (GObject *object,
+               guint prop_id,
+               GValue *value,
+               GParamSpec *pspec)
 {
 	DmapdDmapAvRecord *record = DMAPD_DMAP_AV_RECORD (object);
 
@@ -246,17 +246,16 @@ dmapd_daap_record_get_property (GObject *object,
 	}
 }
 
-gboolean dmapd_daap_record_itunes_compat (DmapAvRecord *record)
+gboolean
+dmapd_daap_record_itunes_compat (DmapAvRecord *record)
 {
 	const gchar *format = DMAPD_DMAP_AV_RECORD (record)->priv->format;
 
-	if (! strcmp (format, "mp3"))
-		return TRUE;
-	else
-		return FALSE;
+	return !strcmp (format, "mp3") ? TRUE : FALSE;
 }
 
-GInputStream *dmapd_daap_record_read (DmapAvRecord *record, GError **error)
+GInputStream *
+dmapd_daap_record_read (DmapAvRecord *record, GError **error)
 {
 	GFile *file;
 	GInputStream *fnval = NULL;
@@ -269,7 +268,7 @@ GInputStream *dmapd_daap_record_read (DmapAvRecord *record, GError **error)
 }
 
 static GArray *
-dmapd_daap_record_to_blob (DmapRecord *record)
+_to_blob (DmapRecord *record)
 {
 	/* FIXME: not endian safe. Don't write with one endianness and
 	 * read with another
@@ -288,47 +287,47 @@ dmapd_daap_record_to_blob (DmapRecord *record)
 	g_assert (priv->artist);
 	g_assert (priv->genre);
 
-	blob_add_string (blob, VERSION);
-	blob_add_string (blob, priv->location);
+	util_blob_add_string (blob, VERSION);
+	util_blob_add_string (blob, priv->location);
 
-	blob_add_atomic (blob, (const guint8 *) &(priv->hash->len), sizeof (priv->hash->len));
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->hash->len), sizeof (priv->hash->len));
 	g_array_append_vals (blob, priv->hash->data, priv->hash->len);
 
-	blob_add_atomic (blob, (const guint8 *) &(priv->filesize),
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->filesize),
 			   sizeof (priv->filesize));
 
-	blob_add_string (blob, priv->format);
-	blob_add_string (blob, priv->title);
-	blob_add_string (blob, priv->album);
-	blob_add_string (blob, priv->artist);
-	blob_add_string (blob, priv->genre);
+	util_blob_add_string (blob, priv->format);
+	util_blob_add_string (blob, priv->title);
+	util_blob_add_string (blob, priv->album);
+	util_blob_add_string (blob, priv->artist);
+	util_blob_add_string (blob, priv->genre);
 
-	blob_add_atomic   (blob, (const guint8 *) &(priv->has_video),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->has_video),
 			   sizeof (priv->has_video));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->mediakind),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->mediakind),
 			   sizeof (priv->mediakind));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->rating),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->rating),
 			   sizeof (priv->rating));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->duration),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->duration),
 			   sizeof (priv->duration));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->track),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->track),
 			   sizeof (priv->track));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->year),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->year),
 			   sizeof (priv->year));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->firstseen),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->firstseen),
 			   sizeof (priv->firstseen));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->mtime),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->mtime),
 			   sizeof (priv->mtime));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->disc),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->disc),
 			   sizeof (priv->disc));
-	blob_add_atomic   (blob, (const guint8 *) &(priv->bitrate),
+	util_blob_add_atomic   (blob, (const guint8 *) &(priv->bitrate),
 			   sizeof (priv->bitrate));
 	
 	return blob;
 }
 
 static gboolean
-dmapd_daap_record_set_from_blob (DmapRecord *_record, GArray *blob)
+_set_from_blob (DmapRecord *_record, GArray *blob)
 {
 	struct stat buf;
 	gboolean fnval = FALSE;
@@ -432,7 +431,6 @@ dmapd_daap_record_set_from_blob (DmapRecord *_record, GArray *blob)
         ptr += sizeof (record->priv->disc);
 
 	bitrate = *(gint32 *) ptr;
-        ptr += sizeof (record->priv->bitrate);
 
 	file = g_file_new_for_uri (location);
         if (NULL == location) {
@@ -447,7 +445,7 @@ dmapd_daap_record_set_from_blob (DmapRecord *_record, GArray *blob)
 	}
 
 	if (FALSE /* FIXME: calculate_media_hashes */) {
-		if (! dmapd_util_hash_file (location, hash2)
+		if (! util_hash_file (location, hash2)
 		 || memcmp (hash->data, hash2, DMAP_HASH_SIZE)) {
 			g_warning ("Media file hash has changed since being cached\n");
 			goto _done;
@@ -512,22 +510,25 @@ _done:
 	return fnval;
 }
 
-static void dmapd_daap_record_init (DmapdDmapAvRecord *record)
+static void
+dmapd_daap_record_init (DmapdDmapAvRecord *record)
 {
 	record->priv = DMAPD_DMAP_AV_RECORD_GET_PRIVATE (record);
 }
 
-static void dmapd_daap_record_finalize (GObject *object);
+static void
+_finalize (GObject *object);
 
-static void dmapd_daap_record_class_init (DmapdDmapAvRecordClass *klass)
+static void
+dmapd_daap_record_class_init (DmapdDmapAvRecordClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
 	g_type_class_add_private (klass, sizeof (DmapdDmapAvRecordPrivate));
 
-	gobject_class->set_property = dmapd_daap_record_set_property;	
-	gobject_class->get_property = dmapd_daap_record_get_property;	
-	gobject_class->finalize     = dmapd_daap_record_finalize;	
+	gobject_class->set_property = _set_property;
+	gobject_class->get_property = _get_property;
+	gobject_class->finalize     = _finalize;
 
 	g_object_class_override_property (gobject_class, PROP_LOCATION, "location");
 	g_object_class_override_property (gobject_class, PROP_HASH, "hash");
@@ -551,7 +552,8 @@ static void dmapd_daap_record_class_init (DmapdDmapAvRecordClass *klass)
 	g_object_class_override_property (gobject_class, PROP_MEDIAKIND, "mediakind");
 }
 
-static void dmapd_daap_record_daap_iface_init (gpointer iface, gpointer data)
+static void
+_dmap_av_record_iface_init (gpointer iface, gpointer data)
 {
 	DmapAvRecordInterface *daap_record = iface;
 
@@ -561,23 +563,24 @@ static void dmapd_daap_record_daap_iface_init (gpointer iface, gpointer data)
 	daap_record->read = dmapd_daap_record_read;
 }
 
-static void dmapd_daap_record_dmap_iface_init (gpointer iface, gpointer data)
+static void
+_dmap_record_iface_init (gpointer iface, gpointer data)
 {
 	DmapRecordInterface *dmap_record = iface;
 
 	g_assert (G_TYPE_FROM_INTERFACE (dmap_record) == DMAP_TYPE_RECORD);
 
-	dmap_record->to_blob = dmapd_daap_record_to_blob;
-	dmap_record->set_from_blob = dmapd_daap_record_set_from_blob;
+	dmap_record->to_blob = _to_blob;
+	dmap_record->set_from_blob = _set_from_blob;
 }
 
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapAvRecord, dmapd_daap_record, G_TYPE_OBJECT, 
-			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_AV_RECORD, dmapd_daap_record_daap_iface_init)
-			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, dmapd_daap_record_dmap_iface_init))
+			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_AV_RECORD, _dmap_av_record_iface_init)
+			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, _dmap_record_iface_init))
 
 static void
-dmapd_daap_record_finalize (GObject *object)
+_finalize (GObject *object)
 {
 	DmapdDmapAvRecord *record = DMAPD_DMAP_AV_RECORD (object);
 
@@ -586,15 +589,16 @@ dmapd_daap_record_finalize (GObject *object)
 	g_free (record->priv->location);
 	g_free (record->priv->title);
 
-	stringleton_unref (record->priv->format);
-	stringleton_unref (record->priv->album);
-	stringleton_unref (record->priv->artist);
-	stringleton_unref (record->priv->genre);
+	util_stringleton_unref (record->priv->format);
+	util_stringleton_unref (record->priv->album);
+	util_stringleton_unref (record->priv->artist);
+	util_stringleton_unref (record->priv->genre);
 
 	G_OBJECT_CLASS (dmapd_daap_record_parent_class)->finalize (object);
 }
 
-DmapdDmapAvRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader)
+DmapdDmapAvRecord *
+dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 {
 	DmapdDmapAvRecord *record = NULL;
 	guchar hash_buf[DMAP_HASH_SIZE];
@@ -623,7 +627,7 @@ DmapdDmapAvRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader
 		}
 
 		if (FALSE /* FIXME: calculate_media_hashes */) {
-			if (! dmapd_util_hash_file (location, hash_buf)) {
+			if (! util_hash_file (location, hash_buf)) {
 				g_warning ("Unable to hash %s\n", location);
 				goto _done;
 			}
@@ -653,10 +657,10 @@ DmapdDmapAvRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader
 		g_object_set (record, "location",    location,
 		                      "hash",        hash,
 		                      "title",       title,
-		                      "songartist",  unknown,
-		                      "songalbum",   unknown,
-		                      "songgenre",   unknown,
-		                      "format",      unknown,
+		                      "songartist",  _unknown,
+		                      "songalbum",   _unknown,
+		                      "songgenre",   _unknown,
+		                      "format",      _unknown,
 		                      "mediakind",   DMAP_MEDIA_KIND_MUSIC,
 		                      "year",        1985,
 		                      "disc",        1,
