@@ -18,11 +18,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __DMAPD_DMAP_AV_RECORD
-#define __DMAPD_DMAP_AV_RECORD
+#ifndef _DMAPD_DAAP_RECORD_H
+#define _DMAPD_DAAP_RECORD_H
 
 #include <libdmapsharing/dmap.h>
-#include <av-meta-reader.h>
+
+#include "av-meta-reader.h"
 
 G_BEGIN_DECLS
 
@@ -57,6 +58,6 @@ gboolean      dmapd_daap_record_itunes_compat   (DmapAvRecord *record);
 GInputStream *dmapd_daap_record_read            (DmapAvRecord *record,
 						 GError **err);
 
-#endif /* __DMAPD_DMAP_AV_RECORD */
-
 G_END_DECLS
+
+#endif
