@@ -51,7 +51,7 @@ dmapd_dmap_container_db_count (DmapContainerDb *db)
 }
 
 void
-dmapd_dmap_container_db_add (DmapContainerDb *db, DmapContainerRecord *record)
+dmapd_dmap_container_db_add (DmapContainerDb *db, DmapContainerRecord *record, GError **error)
 {
         guint id = dmap_container_record_get_id (record);
 	g_object_ref (record);
@@ -69,7 +69,7 @@ dmapd_dmap_container_db_init (DmapdDmapContainerDb *db)
 }
 
 static void
-dmapd_dmap_container_db_finalize (GObject *object)
+_finalize (GObject *object)
 {
         DmapdDmapContainerDb *db = DMAPD_DMAP_CONTAINER_DB (object);
 
@@ -83,13 +83,13 @@ dmapd_dmap_container_db_class_init (DmapdDmapContainerDbClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->finalize = dmapd_dmap_container_db_finalize;
+        object_class->finalize = _finalize;
 
         g_type_class_add_private (klass, sizeof (DmapdDmapContainerDbPrivate));
 }
 
 static void
-dmapd_dmap_container_db_interface_init (gpointer iface, gpointer data)
+_dmap_container_db_interface_init (gpointer iface, gpointer data)
 {
 	DmapContainerDbInterface *dmap_container_db = iface;
 
@@ -103,7 +103,7 @@ dmapd_dmap_container_db_interface_init (gpointer iface, gpointer data)
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapContainerDb, dmapd_dmap_container_db, G_TYPE_OBJECT, 
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_CONTAINER_DB,
-						dmapd_dmap_container_db_interface_init))
+						_dmap_container_db_interface_init))
 
 DmapdDmapContainerDb *
 dmapd_dmap_container_db_new (void)
