@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __DMAPD_DMAP_CONTAINER_DB
-#define __DMAPD_DMAP_CONTAINER_DB
+#ifndef _DMAPD_DMAP_CONTAINER_DB_H
+#define _DMAPD_DMAP_CONTAINER_DB_H
 
 #include <libdmapsharing/dmap.h>
 
@@ -63,8 +63,10 @@ void        dmapd_dmap_container_db_foreach (DmapContainerDb *db,
 
 gint64      dmapd_dmap_container_db_count (DmapContainerDb *db);
 
-void dmapd_dmap_container_db_add (DmapContainerDb *db, DmapContainerRecord *record);
-
-#endif /* __DMAPD_DMAP_CONTAINER_DB */
+void dmapd_dmap_container_db_add (DmapContainerDb *db,
+                                  DmapContainerRecord *record,
+                                  GError **error);
 
 G_END_DECLS
+
+#endif
