@@ -27,7 +27,7 @@
 #include "dmapd-dmap-db-disk.h"
 
 /* Media ID's start at max and go down. Container ID's start at 1 and go up. */
-static guint nextid = G_MAXINT; /* NOTE: this should be G_MAXUINT, but iPhoto can't handle it. */
+static guint _nextid = G_MAXINT; /* NOTE: this should be G_MAXUINT, but iPhoto can't handle it. */
 
 struct DmapdDmapDbDiskPrivate {
 	GHashTable *db;
@@ -45,7 +45,7 @@ struct fn_data_t {
 };
 
 static GArray *
-cache_read (const gchar *path)
+_cache_read (const gchar *path)
 {
         gchar *data;
         size_t size;
@@ -65,15 +65,18 @@ cache_read (const gchar *path)
 }
 
 static DmapRecord *
-load_cached_record (const DmapDb *db, const gchar *db_dir, guchar *hash, DmapRecordFactory *factory)
+_load_cached_record (const DmapDb *db,
+                     const gchar *db_dir,
+                     guchar *hash,
+                     DmapRecordFactory *factory)
 {
 	DmapRecord *record = NULL;
 	gchar *path = g_strdup_printf ("%s/%s", db_dir, hash);
 	if (g_file_test (path, G_FILE_TEST_IS_REGULAR)) {
-		GArray *blob = cache_read (path);
+		GArray *blob = _cache_read (path);
 		if (blob) {
 			g_debug ("Adding cache: %s", path);
-			record = dmap_record_factory_create (factory, NULL);
+			record = dmap_record_factory_create (factory, NULL, NULL);
 			dmap_record_set_from_blob (record, blob);
 			g_array_free (blob, TRUE);
 		}
@@ -83,7 +86,7 @@ load_cached_record (const DmapDb *db, const gchar *db_dir, guchar *hash, DmapRec
 }
 
 static DmapRecord *
-dmapd_dmap_db_disk_lookup_by_id	(const DmapDb *db, guint id)
+_lookup_by_id (const DmapDb *db, guint id)
 {
 	guchar *hash = NULL;
 	gchar *db_dir = NULL;
@@ -98,7 +101,7 @@ dmapd_dmap_db_disk_lookup_by_id	(const DmapDb *db, guint id)
 	hash = g_hash_table_lookup (DMAPD_DMAP_DB_DISK (db)->priv->db, GUINT_TO_POINTER (id));
 	if (hash) {
 		g_debug ("Hash for %d is %s", id, hash);
-		record = load_cached_record (db, db_dir, hash, factory);
+		record = _load_cached_record (db, db_dir, hash, factory);
 		if (! record) {
 			g_warning ("Record %s not found", hash);
 		}
@@ -110,7 +113,7 @@ dmapd_dmap_db_disk_lookup_by_id	(const DmapDb *db, guint id)
 }
 
 static gboolean
-hash_match (gpointer key, gpointer val, gpointer user_data)
+_hash_match (gpointer key, gpointer val, gpointer user_data)
 {
 	struct hash_id_t *hash_id = user_data;
 	hash_id->id = GPOINTER_TO_UINT (key);
@@ -118,7 +121,7 @@ hash_match (gpointer key, gpointer val, gpointer user_data)
 }
 
 static guint
-dmapd_dmap_db_disk_lookup_id_by_location (const DmapDb *db, const gchar *location)
+_lookup_id_by_location (const DmapDb *db, const gchar *location)
 {
 	guint fnval;
 	guchar hash[33];
@@ -131,7 +134,7 @@ dmapd_dmap_db_disk_lookup_id_by_location (const DmapDb *db, const gchar *locatio
 	user_data.id = 0;
 
 	if (g_hash_table_find (DMAPD_DMAP_DB_DISK (db)->priv->db,
-		(GHRFunc) hash_match,
+		(GHRFunc) _hash_match,
 		(gpointer) &user_data)) {
 		fnval = user_data.id;
 	} else {
@@ -142,7 +145,7 @@ dmapd_dmap_db_disk_lookup_id_by_location (const DmapDb *db, const gchar *locatio
 }
 
 static void
-dmapd_dmap_db_disk_foreach_ghfunc (gpointer key, gpointer value, gpointer user_data)
+_foreach_ghfunc (gpointer key, gpointer value, gpointer user_data)
 {
 
 	DmapRecord *record;
@@ -150,7 +153,7 @@ dmapd_dmap_db_disk_foreach_ghfunc (gpointer key, gpointer value, gpointer user_d
 
 	g_debug ("Processing id %u", GPOINTER_TO_UINT (key));
 
-	record = dmapd_dmap_db_disk_lookup_by_id(fn_data->db, GPOINTER_TO_UINT (key));
+	record = _lookup_by_id(fn_data->db, GPOINTER_TO_UINT (key));
 	if (record) {
 		fn_data->fn (GPOINTER_TO_UINT(key), record, fn_data->user_data);
 		g_object_unref (record);
@@ -160,7 +163,7 @@ dmapd_dmap_db_disk_foreach_ghfunc (gpointer key, gpointer value, gpointer user_d
 }
 
 static void
-dmapd_dmap_db_disk_foreach(const DmapDb *db,
+_foreach(const DmapDb *db,
                            DmapIdRecordFunc func,
                            gpointer data)
 {
@@ -168,17 +171,17 @@ dmapd_dmap_db_disk_foreach(const DmapDb *db,
 	user_data.db = db;
 	user_data.fn = func;
 	user_data.user_data = data;
-	g_hash_table_foreach (DMAPD_DMAP_DB_DISK (db)->priv->db, dmapd_dmap_db_disk_foreach_ghfunc, &user_data);
+	g_hash_table_foreach (DMAPD_DMAP_DB_DISK (db)->priv->db, _foreach_ghfunc, &user_data);
 }
 
 static gint64
-dmapd_dmap_db_disk_count (const DmapDb *db)
+_disk_count (const DmapDb *db)
 {
 	return g_hash_table_size (DMAPD_DMAP_DB_DISK (db)->priv->db);
 }
 
 static guint
-dmapd_dmap_db_disk_add_with_id (DmapDb *db, DmapRecord *record, guint id)
+_add_with_id (DmapDb *db, DmapRecord *record, guint id, GError **error)
 {
 	gchar *location;
 	GArray *blob;
@@ -198,7 +201,7 @@ dmapd_dmap_db_disk_add_with_id (DmapDb *db, DmapRecord *record, guint id)
         dmap_md5_generate (1, (const guchar*) location, 2, hash, 0);
 
 	blob = dmap_record_to_blob (record);
-	cache_store (db_dir, location, blob);
+	util_cache_store (db_dir, location, blob);
 	g_free (location);
 	g_array_free (blob, TRUE);
 	g_hash_table_insert (DMAPD_DMAP_DB_DISK (db)->priv->db, GUINT_TO_POINTER (id), hash);
@@ -207,13 +210,13 @@ dmapd_dmap_db_disk_add_with_id (DmapDb *db, DmapRecord *record, guint id)
 }
 
 static guint
-dmapd_dmap_db_disk_add (DmapDb *db, DmapRecord *record)
+_add (DmapDb *db, DmapRecord *record, GError **error)
 {
-	return dmapd_dmap_db_disk_add_with_id (db, record, nextid--);
+	return _add_with_id (db, record, _nextid--, error);
 }
 
 static guint
-dmapd_dmap_db_disk_add_path (DmapDb *db, const gchar *path)
+_add_path (DmapDb *db, const gchar *path, GError **error)
 {
 	guint id;
 	DmapRecord *record;
@@ -221,10 +224,10 @@ dmapd_dmap_db_disk_add_path (DmapDb *db, const gchar *path)
 
 	g_object_get (db, "record-factory", &factory, NULL);
 	g_assert (factory);
-	record = dmap_record_factory_create (factory, (gpointer) path);
+	record = dmap_record_factory_create (factory, (gpointer) path, error);
 
 	if (record) {
-		id = dmapd_dmap_db_disk_add (db, record);
+		id = _add (db, record, error);
 		g_object_unref (record);
 	} else {
 		id = 0;
@@ -233,9 +236,7 @@ dmapd_dmap_db_disk_add_path (DmapDb *db, const gchar *path)
 	return id;
 }
 
-G_DEFINE_DYNAMIC_TYPE (DmapdDmapDbDisk,
-		       dmapd_dmap_db_disk,
-		       TYPE_DMAPD_DMAP_DB)
+G_DEFINE_DYNAMIC_TYPE (DmapdDmapDbDisk, dmapd_dmap_db_disk, TYPE_DMAPD_DMAP_DB)
 
 static void dmapd_dmap_db_disk_init (DmapdDmapDbDisk *db)
 {
@@ -247,7 +248,7 @@ static void dmapd_dmap_db_disk_init (DmapdDmapDbDisk *db)
 }
 
 static void
-dmapd_dmap_db_disk_finalize (GObject *object)
+_finalize (GObject *object)
 {
 	DmapdDmapDbDisk *db = DMAPD_DMAP_DB_DISK (object);
 
@@ -267,15 +268,15 @@ static void dmapd_dmap_db_disk_class_init (DmapdDmapDbDiskClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	DmapdDmapDbClass *dmap_db_class = DMAPD_DMAP_DB_CLASS (klass);
 
-	object_class->finalize = dmapd_dmap_db_disk_finalize;
+	object_class->finalize = _finalize;
 
-	dmap_db_class->add = dmapd_dmap_db_disk_add;
-	dmap_db_class->add_with_id = dmapd_dmap_db_disk_add_with_id;
-	dmap_db_class->add_path = dmapd_dmap_db_disk_add_path;
-	dmap_db_class->lookup_by_id = dmapd_dmap_db_disk_lookup_by_id;
-	dmap_db_class->lookup_id_by_location = dmapd_dmap_db_disk_lookup_id_by_location;
-	dmap_db_class->foreach = dmapd_dmap_db_disk_foreach;
-	dmap_db_class->count = dmapd_dmap_db_disk_count;
+	dmap_db_class->add = _add;
+	dmap_db_class->add_with_id = _add_with_id;
+	dmap_db_class->add_path = _add_path;
+	dmap_db_class->lookup_by_id = _lookup_by_id;
+	dmap_db_class->lookup_id_by_location = _lookup_id_by_location;
+	dmap_db_class->foreach = _foreach;
+	dmap_db_class->count = _disk_count;
 
 	g_type_class_add_private (klass, sizeof (DmapdDmapDbDiskPrivate));
 }
