@@ -28,7 +28,7 @@
 #include "dmapd-dmap-db-ghashtable.h"
 
 /* Media ID's start at max and go down. Container ID's start at 1 and go up. */
-static guint nextid = G_MAXINT; /* NOTE: this should be G_MAXUINT, but iPhoto can't handle it. */
+static guint _nextid = G_MAXINT; /* NOTE: this should be G_MAXUINT, but iPhoto can't handle it. */
 
 struct DmapdDmapDbGHashTablePrivate {
 	GHashTable *db;
@@ -50,7 +50,7 @@ struct loc_id {
 };
 
 static gboolean
-path_match (gpointer key, gpointer val, gpointer user_data)
+_path_match (gpointer key, gpointer val, gpointer user_data)
 {
 	gboolean fnval;
 	gchar *location;
@@ -66,7 +66,7 @@ path_match (gpointer key, gpointer val, gpointer user_data)
 }
 
 static guint
-dmapd_dmap_db_ghashtable_lookup_id_by_location (const DmapDb *db, const gchar *location)
+_lookup_id_by_location (const DmapDb *db, const gchar *location)
 {
 	guint fnval;
 	struct loc_id user_data;
@@ -75,7 +75,7 @@ dmapd_dmap_db_ghashtable_lookup_id_by_location (const DmapDb *db, const gchar *l
 	user_data.id = 0;
 
 	if (g_hash_table_find (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db,
-		(GHRFunc) path_match,
+		(GHRFunc) _path_match,
 		(gpointer) &user_data)) {
 		fnval = user_data.id;
 	} else {
@@ -86,7 +86,7 @@ dmapd_dmap_db_ghashtable_lookup_id_by_location (const DmapDb *db, const gchar *l
 }
 
 static DmapRecord *
-dmapd_dmap_db_ghashtable_lookup_by_id	(const DmapDb *db, guint id)
+_lookup_by_id (const DmapDb *db, guint id)
 {
 	DmapRecord *record;
 
@@ -97,21 +97,19 @@ dmapd_dmap_db_ghashtable_lookup_by_id	(const DmapDb *db, guint id)
 }
 
 static void
-dmapd_dmap_db_ghashtable_foreach(const DmapDb *db,
-				 DmapIdRecordFunc func,
-				 gpointer data)
+_foreach(const DmapDb *db, DmapIdRecordFunc func, gpointer data)
 {
 	g_hash_table_foreach (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db, (GHFunc) func, data);
 }
 
 static gint64
-dmapd_dmap_db_ghashtable_count (const DmapDb *db)
+_count (const DmapDb *db)
 {
 	return g_hash_table_size (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db);
 }
 
 static GArray *
-cache_read (const gchar *path)
+_cache_read (const gchar *path)
 {
         gchar *data;
         size_t size;
@@ -131,22 +129,25 @@ cache_read (const gchar *path)
 }
 
 static guint
-dmapd_dmap_db_ghashtable_add_with_id (DmapDb *db, DmapRecord *record, guint id)
+_add_with_id (DmapDb *db, DmapRecord *record, guint id, GError **error)
 {
-	g_hash_table_insert (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db, GUINT_TO_POINTER (id), record);
+	if (id > 0) {
+		g_hash_table_insert (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db, GUINT_TO_POINTER (id), record);
+	}
+
 	return id;
 }
 
 static guint
-dmapd_dmap_db_ghashtable_add_no_cache (DmapDb *db, DmapRecord *record)
+_add_no_cache (DmapDb *db, DmapRecord *record, GError **error)
 {
 	g_object_ref (record);
 
-	return dmapd_dmap_db_ghashtable_add_with_id (db, record, nextid--);
+	return _add_with_id (db, record, _nextid--, error);
 }
 
 static void
-load_cached_records (DmapDb *db, const gchar *db_dir, DmapRecordFactory *factory)
+_load_cached_records (DmapDb *db, const gchar *db_dir, DmapRecordFactory *factory)
 {
 	GDir *d;
 	GError *error = NULL;
@@ -164,13 +165,13 @@ load_cached_records (DmapDb *db, const gchar *db_dir, DmapRecordFactory *factory
 				gchar *path = g_strdup_printf ("%s/%s", db_dir, entry);
 				if (g_file_test (path, G_FILE_TEST_IS_REGULAR)
 				    && g_str_has_suffix (path, ".record")) {
-					GArray *blob = cache_read (path);
+					GArray *blob = _cache_read (path);
 					if (blob) {
 						g_debug ("Adding cache: %s", path);
-						DmapRecord *record = dmap_record_factory_create (factory, NULL);
+						DmapRecord *record = dmap_record_factory_create (factory, NULL, &error);
 						if (NULL != record) {
 							if (dmap_record_set_from_blob (record, blob)) {
-								dmapd_dmap_db_ghashtable_add_no_cache (DMAP_DB (db), record);
+								_add_no_cache (DMAP_DB (db), record, NULL);
 							} else {
 								g_warning ("Removing stale cache entry %s\n", path);
 								g_unlink (path);
@@ -189,7 +190,7 @@ load_cached_records (DmapDb *db, const gchar *db_dir, DmapRecordFactory *factory
 }
 
 static guint
-dmapd_dmap_db_ghashtable_add (DmapDb *db, DmapRecord *record)
+_add (DmapDb *db, DmapRecord *record, GError **error)
 {
 	gchar *db_dir   = NULL;
 	GArray *blob    = NULL;
@@ -200,7 +201,7 @@ dmapd_dmap_db_ghashtable_add (DmapDb *db, DmapRecord *record)
 
 	if (db_dir != NULL) {
 		blob = dmap_record_to_blob (record);
-		cache_store (db_dir, location, blob);
+		util_cache_store (db_dir, location, blob);
 	}
 
 	if (NULL != location) {
@@ -215,11 +216,11 @@ dmapd_dmap_db_ghashtable_add (DmapDb *db, DmapRecord *record)
 		g_array_unref (blob);
 	}
 
-	return dmapd_dmap_db_ghashtable_add_no_cache (db, record);
+	return _add_no_cache (db, record, error);
 }
 
 static guint
-dmapd_dmap_db_ghashtable_add_path (DmapDb *db, const gchar *path)
+_add_path (DmapDb *db, const gchar *path, GError **error)
 {
 	guint id = 0;
 	DmapRecord *record;
@@ -227,8 +228,8 @@ dmapd_dmap_db_ghashtable_add_path (DmapDb *db, const gchar *path)
 
 	g_object_get (db, "record-factory", &factory, NULL);
 	g_assert (factory);
-	record = dmap_record_factory_create (factory, (gpointer) path);
 
+	record = dmap_record_factory_create (factory, (gpointer) path, error);
 	if (record) {
 		char *format = NULL;
 		const gchar * const *acceptable_formats = NULL;
@@ -237,7 +238,7 @@ dmapd_dmap_db_ghashtable_add_path (DmapDb *db, const gchar *path)
 		g_object_get (db, "acceptable-formats", &acceptable_formats, NULL);
 
 		if (! acceptable_formats || g_strv_contains(acceptable_formats, format)) {
-			id = dmapd_dmap_db_ghashtable_add (db, record);
+			id = _add (db, record, error);
 		}
 
 		if (NULL != format) {
@@ -250,26 +251,27 @@ dmapd_dmap_db_ghashtable_add_path (DmapDb *db, const gchar *path)
 	return id;
 }
 
-static void dmapd_dmap_ghashtable_interface_init (gpointer iface, gpointer data)
+static void
+_dmap_db_interface_init (gpointer iface, gpointer data)
 {
         DmapDbInterface *dmap_db = iface;
 
 	g_assert (G_TYPE_FROM_INTERFACE (dmap_db) == DMAP_TYPE_DB);
 
-	dmap_db->add = dmapd_dmap_db_ghashtable_add;
-	dmap_db->add_with_id = dmapd_dmap_db_ghashtable_add_with_id;
-	dmap_db->add_path = dmapd_dmap_db_ghashtable_add_path;
-	dmap_db->lookup_by_id = dmapd_dmap_db_ghashtable_lookup_by_id;
-	dmap_db->lookup_id_by_location = dmapd_dmap_db_ghashtable_lookup_id_by_location;
-	dmap_db->foreach = dmapd_dmap_db_ghashtable_foreach;
-	dmap_db->count = dmapd_dmap_db_ghashtable_count;
+	dmap_db->add = _add;
+	dmap_db->add_with_id = _add_with_id;
+	dmap_db->add_path = _add_path;
+	dmap_db->lookup_by_id = _lookup_by_id;
+	dmap_db->lookup_id_by_location = _lookup_id_by_location;
+	dmap_db->foreach = _foreach;
+	dmap_db->count = _count;
 }
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapDbGHashTable, dmapd_dmap_db_ghashtable, G_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (DMAP_TYPE_DB, dmapd_dmap_ghashtable_interface_init))
+                         G_IMPLEMENT_INTERFACE (DMAP_TYPE_DB, _dmap_db_interface_init))
 
 static GObject*
-dmapd_dmap_db_ghashtable_constructor (GType type, guint n_construct_params, GObjectConstructParam *construct_params)
+_constructor (GType type, guint n_construct_params, GObjectConstructParam *construct_params)
 {
 	GObject *object;
 	gchar *db_dir = NULL;
@@ -280,14 +282,15 @@ dmapd_dmap_db_ghashtable_constructor (GType type, guint n_construct_params, GObj
 	g_object_get (object, "db-dir", &db_dir, "record-factory", &factory, NULL);
 	/* NOTE: Don't load cache when used for DmapdDmapContainerRecord: */
 	if (db_dir && factory) {
-		load_cached_records (DMAP_DB (object), db_dir, factory);
+		_load_cached_records (DMAP_DB (object), db_dir, factory);
 	}
 	g_free (db_dir);
 
 	return object;
 }
 
-static void dmapd_dmap_db_ghashtable_init (DmapdDmapDbGHashTable *db)
+static void
+dmapd_dmap_db_ghashtable_init (DmapdDmapDbGHashTable *db)
 {
 	db->priv = DMAPD_DMAP_DB_GHASHTABLE_GET_PRIVATE (db);
 	db->priv->db = g_hash_table_new_full (g_direct_hash,
@@ -297,7 +300,7 @@ static void dmapd_dmap_db_ghashtable_init (DmapdDmapDbGHashTable *db)
 }
 
 static void
-dmapd_dmap_db_ghashtable_finalize (GObject *object)
+_finalize (GObject *object)
 {
 	DmapdDmapDbGHashTable *db = DMAPD_DMAP_DB_GHASHTABLE (object);
 
@@ -308,10 +311,10 @@ dmapd_dmap_db_ghashtable_finalize (GObject *object)
 }
 
 static void
-dmapd_dmap_db_ghashtable_set_property (GObject *object,
-                            guint prop_id,
-			    const GValue *value,
-			    GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
         DmapdDmapDbGHashTable *db = DMAPD_DMAP_DB_GHASHTABLE (object);
 
@@ -321,8 +324,9 @@ dmapd_dmap_db_ghashtable_set_property (GObject *object,
 			db->priv->db_dir = g_value_dup_string (value);
 			break;
 		case PROP_RECORD_FACTORY:
-			if (db->priv->record_factory)
+			if (db->priv->record_factory) {
 				g_object_unref (db->priv->record_factory);
+			}
 			db->priv->record_factory = DMAP_RECORD_FACTORY (g_value_get_pointer (value));
 			break;	
 		case PROP_ACCEPTABLE_FORMATS:
@@ -335,10 +339,10 @@ dmapd_dmap_db_ghashtable_set_property (GObject *object,
 }
 
 static void
-dmapd_dmap_db_ghashtable_get_property (GObject *object,
-                            guint prop_id,
-			    GValue *value,
-			    GParamSpec *pspec)
+_get_property (GObject *object,
+               guint prop_id,
+               GValue *value,
+               GParamSpec *pspec)
 {
         DmapdDmapDbGHashTable *db = DMAPD_DMAP_DB_GHASHTABLE (object);
 
@@ -365,10 +369,10 @@ static void dmapd_dmap_db_ghashtable_class_init (DmapdDmapDbGHashTableClass *kla
 
 	g_type_class_add_private (klass, sizeof (DmapdDmapDbGHashTablePrivate));
 
-	object_class->finalize = dmapd_dmap_db_ghashtable_finalize;
-	object_class->constructor = dmapd_dmap_db_ghashtable_constructor;
-	object_class->set_property = dmapd_dmap_db_ghashtable_set_property;
-	object_class->get_property = dmapd_dmap_db_ghashtable_get_property;
+	object_class->finalize     = _finalize;
+	object_class->constructor  = _constructor;
+	object_class->set_property = _set_property;
+	object_class->get_property = _get_property;
 
 	g_object_class_install_property (object_class,
 					 PROP_RECORD_FACTORY,
