@@ -61,10 +61,10 @@ enum {
 };
 
 static void
-dmapd_dpap_record_set_property (GObject *object,
-				guint prop_id,
-				const GValue *value,
-				GParamSpec *pspec)
+_set_property (GObject *object,
+               guint prop_id,
+               const GValue *value,
+               GParamSpec *pspec)
 {
 	DmapdDmapImageRecord *record = DMAPD_DPAP_RECORD (object);
 
@@ -93,8 +93,8 @@ dmapd_dpap_record_set_property (GObject *object,
 			record->priv->filename = g_value_dup_string (value);
 			break;
 		case PROP_ASPECT_RATIO:
-			stringleton_unref (record->priv->aspectratio);
-			record->priv->aspectratio = stringleton_ref (g_value_get_string (value));
+			util_stringleton_unref (record->priv->aspectratio);
+			record->priv->aspectratio = util_stringleton_ref (g_value_get_string (value));
 			break;
 		case PROP_PIXEL_HEIGHT:
 			record->priv->height = g_value_get_int (value);
@@ -103,8 +103,8 @@ dmapd_dpap_record_set_property (GObject *object,
 			record->priv->width = g_value_get_int (value);
 			break;
 		case PROP_FORMAT:
-			stringleton_unref (record->priv->format);
-			record->priv->format = stringleton_ref (g_value_get_string (value));
+			util_stringleton_unref (record->priv->format);
+			record->priv->format = util_stringleton_ref (g_value_get_string (value));
 			break;
 		case PROP_COMMENTS:
 			g_free (record->priv->comments);
@@ -127,10 +127,10 @@ dmapd_dpap_record_set_property (GObject *object,
 }
 
 static void
-dmapd_dpap_record_get_property (GObject *object,
-                                guint prop_id,
-				GValue *value,
-				GParamSpec *pspec)
+_get_property (GObject *object,
+               guint prop_id,
+               GValue *value,
+               GParamSpec *pspec)
 {
 	DmapdDmapImageRecord *record = DMAPD_DPAP_RECORD (object);
 
@@ -181,7 +181,8 @@ dmapd_dpap_record_get_property (GObject *object,
 	}
 }
 
-GInputStream *dmapd_dpap_record_read (DmapImageRecord *record, GError **error)
+GInputStream *
+dmapd_dpap_record_read (DmapImageRecord *record, GError **error)
 {
         GFile *file;
         GInputStream *stream;
@@ -195,7 +196,7 @@ GInputStream *dmapd_dpap_record_read (DmapImageRecord *record, GError **error)
 }
 
 static GArray *
-dmapd_dpap_record_to_blob (DmapRecord *record)
+_to_blob (DmapRecord *record)
 {
 	/* FIXME: not endian safe. Don't write with one endianness and 
 	 * read with another
@@ -214,21 +215,21 @@ dmapd_dpap_record_to_blob (DmapRecord *record)
         g_assert (priv->format);
         g_assert (priv->comments);
 
-	blob_add_string (blob, VERSION);
-	blob_add_string (blob, priv->location);
+	util_blob_add_string (blob, VERSION);
+	util_blob_add_string (blob, priv->location);
 
-	blob_add_atomic (blob, (const guint8 *) &(priv->hash->len), sizeof (priv->hash->len));
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->hash->len), sizeof (priv->hash->len));
 	g_array_append_vals (blob, priv->hash->data, priv->hash->len);
 
-	blob_add_atomic (blob, (const guint8 *) &(priv->largefilesize),
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->largefilesize),
 			 sizeof (priv->largefilesize));
-	blob_add_atomic (blob, (const guint8 *) &(priv->creationdate),
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->creationdate),
 			 sizeof (priv->creationdate));
-	blob_add_atomic (blob, (const guint8 *) &(priv->rating),
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->rating),
 			 sizeof (priv->rating));
-        blob_add_string (blob, priv->filename);
+        util_blob_add_string (blob, priv->filename);
 	if (priv->thumbnail) {
-		blob_add_atomic (blob, (const guint8 *) &(priv->thumbnail->len),
+		util_blob_add_atomic (blob, (const guint8 *) &(priv->thumbnail->len),
 				 sizeof (priv->thumbnail->len));
 
 		g_array_append_vals (blob,
@@ -236,25 +237,25 @@ dmapd_dpap_record_to_blob (DmapRecord *record)
 				     priv->thumbnail->len);
 	} else {
 		gsize zero = 0;
-		blob_add_atomic (blob, (const guint8 *) &zero,
+		util_blob_add_atomic (blob, (const guint8 *) &zero,
 				 sizeof (priv->thumbnail->len));
 	}
 
-        blob_add_string (blob, priv->aspectratio);
-	blob_add_atomic (blob, (const guint8 *) &(priv->height),
+        util_blob_add_string (blob, priv->aspectratio);
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->height),
 			 sizeof (priv->height));
-	blob_add_atomic (blob, (const guint8 *) &(priv->width),
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->width),
 			 sizeof (priv->width));
-        blob_add_string (blob, priv->format);
-        blob_add_string (blob, priv->comments);
-	blob_add_atomic   (blob, (const guint8 *) &(priv->mtime),
+        util_blob_add_string (blob, priv->format);
+        util_blob_add_string (blob, priv->comments);
+	util_blob_add_atomic (blob, (const guint8 *) &(priv->mtime),
                            sizeof (priv->mtime));
 
 	return blob;
 }
 
 static gboolean
-dmapd_dpap_record_set_from_blob (DmapRecord *_record, GArray *blob)
+_set_from_blob (DmapRecord *_record, GArray *blob)
 {
 	struct stat buf;
 	gboolean fnval = FALSE;
@@ -348,7 +349,6 @@ dmapd_dpap_record_set_from_blob (DmapRecord *_record, GArray *blob)
 	ptr += strlen ((char *) ptr) + 1;
 
 	mtime = *(gint32 *) ptr;
-        ptr += sizeof (record->priv->mtime);
 
 	file = g_file_new_for_uri (location);
 	if (NULL == file) {
@@ -363,7 +363,7 @@ dmapd_dpap_record_set_from_blob (DmapRecord *_record, GArray *blob)
         }
 
 	if (FALSE /* FIXME: calculate_media_hashes */) {
-                if (! dmapd_util_hash_file (location, hash2)
+                if (! util_hash_file (location, hash2)
                  || memcmp (hash->data, hash2, DMAP_HASH_SIZE)) {
                         g_warning ("Media file hash has changed since being cached\n");
                         goto _done;
@@ -414,10 +414,7 @@ _done:
                 g_object_unref (file);
         }
 
-	if (NULL != path) {
-                g_free (path);
-        }
-
+	g_free (path);
 
         if (NULL != stream) {
                 g_object_unref (stream);
@@ -439,7 +436,7 @@ static void dmapd_dpap_record_init (DmapdDmapImageRecord *record)
 	record->priv = DMAPD_DPAP_RECORD_GET_PRIVATE (record);
 }
 
-static void dmapd_dpap_record_finalize (GObject *object);
+static void _finalize (GObject *object);
 
 static void dmapd_dpap_record_class_init (DmapdDmapImageRecordClass *klass)
 {
@@ -447,9 +444,9 @@ static void dmapd_dpap_record_class_init (DmapdDmapImageRecordClass *klass)
 
 	g_type_class_add_private (klass, sizeof (DmapdDmapImageRecordPrivate));
 
-	gobject_class->set_property = dmapd_dpap_record_set_property;
-	gobject_class->get_property = dmapd_dpap_record_get_property;
-	gobject_class->finalize = dmapd_dpap_record_finalize;
+	gobject_class->set_property = _set_property;
+	gobject_class->get_property = _get_property;
+	gobject_class->finalize = _finalize;
 
 	g_object_class_override_property (gobject_class, PROP_LOCATION, "location");
 	g_object_class_override_property (gobject_class, PROP_HASH, "hash");
@@ -473,7 +470,8 @@ static void dmapd_dpap_record_class_init (DmapdDmapImageRecordClass *klass)
                                           G_PARAM_READWRITE));
 }
 
-static void dmapd_dpap_record_dpap_iface_init (gpointer iface, gpointer data)
+static void
+_dmap_image_record_iface_init (gpointer iface, gpointer data)
 {
 	DmapImageRecordInterface *dpap_record = iface;
 
@@ -482,30 +480,31 @@ static void dmapd_dpap_record_dpap_iface_init (gpointer iface, gpointer data)
 	dpap_record->read = dmapd_dpap_record_read;
 }
 
-static void dmapd_dpap_record_dmap_iface_init (gpointer iface, gpointer data)
+static void
+_dmap_record_iface_init (gpointer iface, gpointer data)
 {
 	DmapRecordInterface *dmap_record = iface;
 
 	g_assert (G_TYPE_FROM_INTERFACE (dmap_record) == DMAP_TYPE_RECORD);
 
-	dmap_record->to_blob = dmapd_dpap_record_to_blob;
-	dmap_record->set_from_blob = dmapd_dpap_record_set_from_blob;
+	dmap_record->to_blob = _to_blob;
+	dmap_record->set_from_blob = _set_from_blob;
 }
 
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapImageRecord, dmapd_dpap_record, G_TYPE_OBJECT, 
-			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_IMAGE_RECORD, dmapd_dpap_record_dpap_iface_init)
-			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, dmapd_dpap_record_dmap_iface_init))
+			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_IMAGE_RECORD, _dmap_image_record_iface_init)
+			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, _dmap_record_iface_init))
 
 static void
-dmapd_dpap_record_finalize (GObject *object)
+_finalize (GObject *object)
 {
         DmapdDmapImageRecord *record = DMAPD_DPAP_RECORD (object);
 
 	g_debug ("Free'ing record");
 
-	stringleton_unref (record->priv->aspectratio);
-	stringleton_unref (record->priv->format);
+	util_stringleton_unref (record->priv->aspectratio);
+	util_stringleton_unref (record->priv->format);
 
 	g_free (record->priv->location);
 	g_free (record->priv->filename);
@@ -522,7 +521,8 @@ dmapd_dpap_record_finalize (GObject *object)
 	G_OBJECT_CLASS (dmapd_dpap_record_parent_class)->finalize (object);
 }
 
-DmapdDmapImageRecord *dmapd_dpap_record_new (const char *path, gpointer reader)
+DmapdDmapImageRecord *
+dmapd_dpap_record_new (const char *path, gpointer reader)
 {
 	DmapdDmapImageRecord *record = NULL;
 	guchar hash_buf[DMAP_HASH_SIZE];
@@ -544,7 +544,7 @@ DmapdDmapImageRecord *dmapd_dpap_record_new (const char *path, gpointer reader)
                 }
 
 		if (FALSE /* FIXME: calculate_media_hashes */) {
-			if (! dmapd_util_hash_file (location, hash_buf)) {
+			if (! util_hash_file (location, hash_buf)) {
 				g_warning ("Unable to hash %s\n", location);
 				goto _done;
 			}
