@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __DMAPD_DPAP_RECORD
-#define __DMAPD_DPAP_RECORD
+#ifndef _DMAPD_DPAP_RECORD_H
+#define _DMAPD_DPAP_RECORD_H
 
 #include <libdmapsharing/dmap.h>
 
@@ -51,6 +51,6 @@ DmapdDmapImageRecord *dmapd_dpap_record_new (const char *location, gpointer read
 GInputStream  *dmapd_dpap_record_read              (DmapImageRecord *record,
 						    GError **err);
 
-#endif /* __DMAPD_DPAP_RECORD */
-
 G_END_DECLS
+
+#endif
