@@ -28,7 +28,8 @@
 
 #include "util.h"
 
-int main (int argc, char *argv[])
+int
+main (int argc, char *argv[])
 {
 	guchar raw_hash[DMAP_HASH_SIZE] = { 0 };
 	gchar hash[DMAP_HASH_SIZE * 2 + 1] = { 0 };
@@ -59,7 +60,7 @@ int main (int argc, char *argv[])
 		g_error ("Could not convert %s to a URI", argv[1]);
 	}
 
-	if (! dmapd_util_hash_file (uri, raw_hash)) {
+	if (! util_hash_file (uri, raw_hash)) {
 		exit (EXIT_FAILURE);
         }
 
