@@ -90,10 +90,10 @@ static gchar  **_music_formats            = NULL;
 static gchar  **_picture_formats          = NULL;
 static gchar   *_module_dir               = NULL;
 static gchar   *_config_file              = DEFAULT_CONFIG_FILE;
-static gchar   *_db_dir                   = DEFAULT_DBDIR;
-static gchar   *_lockpath                 = DEFAULT_LOCKPATH;
+static gchar   *_db_dir                   = NULL;
+static gchar   *_lockpath                 = NULL;
 static gchar   *_password                 = NULL;
-static gchar   *_pidpath                  = DEFAULT_RUNDIR "/dmapd.pid";
+static gchar   *_pidpath                  = NULL;
 static gchar   *_user                     = NULL;
 static gchar   *_group                    = NULL;
 static gchar   *_share_name               = NULL;
@@ -288,6 +288,7 @@ _daemonize (void)
 	int child, fd;
 	char *pid;
 	ssize_t size;
+	char *lockpath, *pidpath;
 
 	child = fork ();
 
@@ -307,25 +308,27 @@ _daemonize (void)
 		g_error("Error chdir to %s: %s", DEFAULT_RUNDIR, strerror(errno));
 	}
 
-	fd = open (_lockpath, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
+	lockpath = _lockpath ? _lockpath : DEFAULT_LOCKPATH;
+	fd = open (lockpath, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
 	if (-1 == fd) {
-		g_error("Error opening %s: %s", _lockpath, strerror(errno));
+		g_error("Error opening %s: %s", lockpath, strerror(errno));
 	}
 
 	if (-1 == lockf (fd, F_TLOCK, 0)) {
-		g_error("Error locking %s: %s", _lockpath, strerror(errno));
+		g_error("Error locking %s: %s", lockpath, strerror(errno));
 	}
 	
-	fd = open (_pidpath, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
+	pidpath = _pidpath ? _pidpath : DEFAULT_RUNDIR "/dmapd.pid";
+	fd = open (pidpath, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
 	if (-1 == fd) {
-		g_error("Error opening %s: %s", _pidpath, strerror(errno));
+		g_error("Error opening %s: %s", pidpath, strerror(errno));
 	}
 
 	pid = g_strdup_printf ("%d", getpid ());
 
 	size = write (fd, pid, strlen (pid));
 	if (strlen (pid) != size) {
-		g_error("Error writing PID file %s: %s", _pidpath, strerror(errno));
+		g_error("Error writing PID file %s: %s", pidpath, strerror(errno));
 	}
 
 	g_free (pid);
@@ -383,24 +386,31 @@ _log_printf(const char *log_domain,
 		    message);
 }
 
+static void
+_error_cb(DmapShare *share, GError *error, gpointer user_data)
+{
+	g_printerr("%s\n", error->message);
+}
+
 static DmapShare *
 _serve (protocol_id_t protocol,
         DmapRecordFactory *factory,
-        share_def_t *share_def)
+        share_def_t *share_def,
+        GError **error)
 {
-	DmapDb *db;
+	DmapDb *db = NULL;
 	gboolean ok;
-	DmapShare *share;
+	DmapShare *share = NULL;
 	DbBuilder *builder;
-	DmapContainerDb *container_db;
+	DmapContainerDb *container_db = NULL;
 
-	gchar *db_protocol_dir = g_strconcat (_db_dir,
+	gchar *db_protocol_dir = g_strconcat (_db_dir ? _db_dir : DEFAULT_DBDIR,
 	                                     "/",
 	                                      _protocol_map[protocol],
 	                                      NULL);
 	g_assert (_db_module);
 
-	db = DMAP_DB (object_from_module (TYPE_DMAPD_DMAP_DB, 
+	db = DMAP_DB (util_object_from_module (TYPE_DMAPD_DMAP_DB, 
 	                                  _module_dir,
 					  _db_module,
 					  "db-dir",
@@ -415,7 +425,7 @@ _serve (protocol_id_t protocol,
 	}
 
 	container_db = DMAP_CONTAINER_DB (dmapd_dmap_container_db_new ());
-	builder = DB_BUILDER (object_from_module (TYPE_DB_BUILDER,
+	builder = DB_BUILDER (util_object_from_module (TYPE_DB_BUILDER,
 	                                          _module_dir,
 	                                         "gdir",
 	                                          NULL));
@@ -425,40 +435,48 @@ _serve (protocol_id_t protocol,
 	for (int i = 0; share_def->dirs && share_def->dirs[i]; i++) {
 		if (_enable_dir_containers) {
 			g_object_set (builder, "container-db", container_db, NULL);
-			db_builder_build_db_starting_at (builder, share_def->dirs[i], NULL);
-		} else {
-			db_builder_build_db_starting_at (builder, share_def->dirs[i], NULL);
+		}
+
+		ok = db_builder_build_db_starting_at (builder, share_def->dirs[i], NULL, error);
+		if (!ok) {
+			goto done;
 		}
 	}
 
-	if (protocol == DAAP && share_def->transcode_mimetype && ! share_def->enable_rt_transcode)
+	if (protocol == DAAP
+	 && share_def->transcode_mimetype
+	 && ! share_def->enable_rt_transcode) {
 		dmap_db_foreach (db,
-		                (DmapIdRecordFunc) transcode_cache,
-		               &(db_dir_and_target_transcode_mimetype_t) { db_protocol_dir, share_def->transcode_mimetype });
+		                (DmapIdRecordFunc) util_gst_transcode_cache,
+		               &(db_dir_and_target_transcode_mimetype_t) {
+					db_protocol_dir,
+					share_def->transcode_mimetype
+		                });
+	}
 
 	_loop = g_main_loop_new (NULL, FALSE);
-	share = _create_share (protocol, DMAP_DB (db), DMAP_CONTAINER_DB (container_db), share_def);
+	share = _create_share (protocol, db, container_db, share_def);
 
-	ok = dmap_share_serve(share);
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
+
+	ok = dmap_share_serve(share, error);
 	if (!ok) {
 		g_object_unref(share);
 		share = NULL;
 		goto done;
 	}
 
-	ok = dmap_share_publish(share);
+	ok = dmap_share_publish(share, error);
 	if (!ok) {
 		g_object_unref(share);
 		share = NULL;
 		goto done;
 	}
 
-	/* FIXME: Cannot unref here?
-	g_object_unref (db);
-	g_object_unref (container_db);
-	 */
 done:
 	g_object_unref (builder);
+	g_object_unref (container_db);
+	g_object_unref (db);
 
 	g_free (db_protocol_dir);
 
@@ -537,6 +555,11 @@ _read_keyfile (void)
 		shares                = g_key_file_get_groups (keyfile, &num_groups);
 
 		for (i = 0; i < num_groups; i++) {
+			if (!strcmp("General", shares[i])) {
+				/* Every group other than "General" is a share. */
+				continue;
+			}
+
 			_add_share(_read_type(keyfile, shares[i]),
 			           g_strdup(shares[i]),
 			           _key_file_s_or_default (keyfile, shares[i], "Password", _password),
@@ -629,6 +652,7 @@ _raop_service_added_cb (DmapMdnsBrowser *browser,
 			g_debug("Wrong host, %s does not match %s", service_host, host);
 		} else {
 			DmapDb *db;
+			GError *error;
 			DmapContainerDb *container_db;
 
 			g_object_set (workers->av_render, "port", port, NULL);
@@ -651,7 +675,7 @@ _raop_service_added_cb (DmapMdnsBrowser *browser,
 
 			g_signal_connect_object (workers->av_render, "player-updated", G_CALLBACK (_dacp_player_updated_cb), workers->dacp_share, 0);
 
-			dmap_control_share_start_lookup (workers->dacp_share);
+			dmap_control_share_start_lookup (workers->dacp_share, &error);
 
 			// FIXME: this is to test, remove
 			//GList *list = NULL;
@@ -687,7 +711,7 @@ main (int argc, char *argv[])
 	                    _log_printf,
 	                    NULL);
 
-	stringleton_init ();
+	util_stringleton_init ();
 
 	_loop = g_main_loop_new (NULL, FALSE);
 	if (NULL == _loop) {
@@ -720,44 +744,47 @@ main (int argc, char *argv[])
 
 	if (strcmp (_av_meta_reader_module, "null") != 0) {
 		GOptionGroup *group;
-		av_meta_reader = AV_META_READER (object_from_module (TYPE_AV_META_READER,
+		av_meta_reader = AV_META_READER (util_object_from_module (TYPE_AV_META_READER,
 		                                                     _module_dir,
 								     _av_meta_reader_module,
 								     NULL));
 		if (av_meta_reader) {
 			group = av_meta_reader_get_option_group (av_meta_reader);
-			if (group)
+			if (group) {
 				g_option_context_add_group (context, group);
+			}
 		}
 	}
 
 	if (strcmp (_av_render_module, "null") != 0) {
 		GOptionGroup *group;
 		GHashTable *options = g_hash_table_new (g_str_hash, g_str_equal);
-		gchar *mod = parse_plugin_option (_av_render_module, options);
-		workers.av_render = AV_RENDER (object_from_module (TYPE_AV_RENDER,
+		gchar *mod = util_parse_plugin_option (_av_render_module, options);
+		workers.av_render = AV_RENDER (util_object_from_module (TYPE_AV_RENDER,
 		                                                   _module_dir,
 								   mod,
 								   NULL));
 		g_object_set (workers.av_render, "host", g_hash_table_lookup (options, "host"), NULL);
 		if (workers.av_render) {
 			group = av_render_get_option_group (workers.av_render);
-			if (group)
+			if (group) {
 				g_option_context_add_group (context, group);
+			}
 		}
 		g_hash_table_destroy (options);
 	}
 
 	if (strcmp (_photo_meta_reader_module, "null") != 0) {
 		GOptionGroup *group;
-		photo_meta_reader = PHOTO_META_READER (object_from_module (TYPE_PHOTO_META_READER,
+		photo_meta_reader = PHOTO_META_READER (util_object_from_module (TYPE_PHOTO_META_READER,
 									   _module_dir,
 		                                                           _photo_meta_reader_module,
 									   NULL));
 		if (photo_meta_reader) {
 			group = photo_meta_reader_get_option_group (photo_meta_reader);
-			if (group)
+			if (group) {
 				g_option_context_add_group (context, group);
+			}
 		}
 	}
 
@@ -774,7 +801,7 @@ main (int argc, char *argv[])
 	}
 
 	if (NULL != _picture_dirs) {
-		_add_share(DAAP, _share_name, _password, _picture_dirs,
+		_add_share(DPAP, _share_name, _password, _picture_dirs,
 		           _picture_formats, NULL, FALSE);
 	}
 
@@ -820,30 +847,38 @@ main (int argc, char *argv[])
 		switch(share_def->type) {
 		case DAAP:
 #if WITH_DAAP
-			if (av_meta_reader == NULL)
+			if (av_meta_reader == NULL) {
 				g_error ("Music directory specified but AV metadata reader module is 'null'");
+			}
 			factory = DMAP_RECORD_FACTORY (
 					g_object_new (
-						TYPE_DMAPD_DMAP_AV_RECORD_FACTORY,
+						TYPE_DMAPD_DMAP_RECORD_FACTORY,
 						"meta-reader",
 						av_meta_reader,
 						NULL));
-			share_def->share = _serve(DAAP, factory, share_def);
+			share_def->share = _serve(DAAP, factory, share_def, &error);
+			if (NULL == share_def->share) {
+				g_error("Error serving: %s\n", error->message);
+			}
 #else
 		g_error ("DAAP support not present");
 #endif
 			break;
 		case DPAP:
 #ifdef WITH_DPAP
-			if (photo_meta_reader == NULL)
+			if (photo_meta_reader == NULL) {
 				g_error ("Photo directory specified but photo metadata reader module is 'null'");
+			}
 			factory = DMAP_RECORD_FACTORY (
 					g_object_new (
 						TYPE_DMAPD_DPAP_RECORD_FACTORY,
 						"meta-reader",
 						photo_meta_reader,
 						NULL));
-			share_def->share = _serve(DPAP, factory, share_def);
+			share_def->share = _serve(DPAP, factory, share_def, &error);
+			if (NULL == share_def->share) {
+				g_error("Error serving: %s\n", error->message);
+			}
 #else
 			g_error ("DPAP support not present");
 #endif
@@ -891,7 +926,7 @@ main (int argc, char *argv[])
 	}
 
 	_free_globals ();
-	stringleton_deinit ();
+	util_stringleton_deinit ();
 	g_debug("Parent exiting");
 
 	exit(exitval);
