@@ -32,7 +32,7 @@
 
 /* FIXME: copied from libdmapsharing: */
 gboolean
-pads_compatible (GstPad *pad1, GstPad *pad2)
+util_gst_pads_compatible (GstPad *pad1, GstPad *pad2)
 {
         gboolean fnval = FALSE;
         GstCaps *res = NULL, *caps1, *caps2;
@@ -70,7 +70,7 @@ done:
 }
 
 gboolean
-transition_pipeline (GstElement *pipeline, GstState state, GstClockTime timeout)
+util_gst_transition_pipeline (GstElement *pipeline, GstState state, GstClockTime timeout)
 {
 	gboolean fnval = TRUE;
 	GstStateChangeReturn sret;
@@ -89,7 +89,7 @@ transition_pipeline (GstElement *pipeline, GstState state, GstClockTime timeout)
 }
 
 static void
-do_transcode (DmapAvRecord *record, gchar *cachepath, gchar* target_mimetype)
+_do_transcode (DmapAvRecord *record, gchar *cachepath, gchar* target_mimetype)
 {
 	gssize read_size;
 	gchar buf[BUFSIZ];
@@ -163,7 +163,7 @@ _return:
  * have no knowledge of the database, db_dir, etc.
  */
 void
-transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_transcode_mimetype_t *df)
+util_gst_transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_transcode_mimetype_t *df)
 {
 	struct stat statbuf;
 	gboolean has_video = FALSE;
@@ -202,7 +202,7 @@ transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_transcode_mim
 		goto _return;
 	}
 
-	cachepath = cache_path (CACHE_TYPE_TRANSCODED_DATA, df->db_dir, location);
+	cachepath = util_cache_path (CACHE_TYPE_TRANSCODED_DATA, df->db_dir, location);
 	if (NULL == cachepath) {
 		g_warning ("Could not determine cache path.");
 		goto _return;
@@ -211,7 +211,7 @@ transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_transcode_mim
 	if (! g_file_test (cachepath, G_FILE_TEST_EXISTS)) {
 		/* FIXME: return value, not void: */
 		g_debug ("Transcoding %s to %s", location, cachepath);
-		do_transcode (record, cachepath, df->target_transcode_mimetype);
+		_do_transcode (record, cachepath, df->target_transcode_mimetype);
 	} else {
 		g_debug ("Found transcoded data at %s for %s", cachepath, location);
 	}
