@@ -34,10 +34,10 @@
 #include "av-render.h"
 #include "photo-meta-reader.h"
 
-static GHashTable *stringleton;
+static GHashTable *_stringleton;
 
 gchar *
-parse_plugin_option (gchar *str, GHashTable *hash_table)
+util_parse_plugin_option (gchar *str, GHashTable *hash_table)
 {
 	// The user may specify, e.g.:
 	//   "gst:sink=foo,opt1=bar,opt2=baz"
@@ -80,25 +80,26 @@ parse_plugin_option (gchar *str, GHashTable *hash_table)
 }
 
 GArray *
-blob_add_atomic (GArray *blob, const guint8 *ptr, const size_t size)
+util_blob_add_atomic (GArray *blob, const guint8 *ptr, const size_t size)
 {
 	return g_array_append_vals (blob, ptr, size);
 }
 
 GArray *
-blob_add_string (GArray *blob, const gchar *str)
+util_blob_add_string (GArray *blob, const gchar *str)
 {
 	return g_array_append_vals (blob,
 	                           (const guint8 *) str,
 	                            strlen (str) + 1);
 }
 
-void stringleton_init (void)
+void 
+util_stringleton_init (void)
 {
 	static gboolean initialized = FALSE;
 
 	if (! initialized) {
-		stringleton = g_hash_table_new_full (g_str_hash,
+		_stringleton = g_hash_table_new_full (g_str_hash,
 						     g_str_equal,
 						     g_free,
 						     NULL);
@@ -107,25 +108,26 @@ void stringleton_init (void)
 	initialized = TRUE;
 }
 
-const gchar *stringleton_ref (const gchar *str)
+const gchar *
+util_stringleton_ref (const gchar *str)
 {
 	gpointer key;
 	gpointer val;
 
-	g_assert (stringleton);
+	g_assert (_stringleton);
 
 	/* NOTE: insert will free passed str if the key already exists,
 	 * not existing key in hash table.
 	 */
-	if (g_hash_table_lookup_extended (stringleton, str, &key, &val)) {
+	if (g_hash_table_lookup_extended (_stringleton, str, &key, &val)) {
 		str = (gchar *) key;
-		g_hash_table_insert (stringleton,
+		g_hash_table_insert (_stringleton,
 				    (gpointer) g_strdup (str),
 		                     val + 1);
 	} else {
 		val = NULL;
 		str = g_strdup (str);
-		g_hash_table_insert (stringleton,
+		g_hash_table_insert (_stringleton,
 				    (gpointer) str,
 		                     val + 1);
 	}
@@ -135,14 +137,15 @@ const gchar *stringleton_ref (const gchar *str)
 	return str;
 }
 
-void stringleton_unref (const gchar *str)
+void
+util_stringleton_unref (const gchar *str)
 {
 	guint count;
 
-	g_assert (stringleton);
+	g_assert (_stringleton);
 
 	if (str != NULL) {
-		count = GPOINTER_TO_UINT (g_hash_table_lookup (stringleton,
+		count = GPOINTER_TO_UINT (g_hash_table_lookup (_stringleton,
 							      (gpointer) str));
 
 		g_debug ("        Decrement stringleton %s reference count to %u.", str, count - 1);
@@ -151,40 +154,48 @@ void stringleton_unref (const gchar *str)
 		 * not existing key in hash table.
 		 */
 		if (count > 1) {
-			g_hash_table_insert (stringleton,
+			g_hash_table_insert (_stringleton,
 					    (gpointer) g_strdup (str),
 					     GUINT_TO_POINTER (count - 1));
 		} else if (count == 1) {
-			g_hash_table_remove (stringleton, (gpointer) str);
+			g_hash_table_remove (_stringleton, (gpointer) str);
 		}
 	}
 }
 
-void stringleton_deinit (void)
+void
+util_stringleton_deinit (void)
 {
-	g_hash_table_destroy (stringleton);
+	g_hash_table_destroy (_stringleton);
 }
 
 static char *
-find_plugin_template (GType type)
+_find_plugin_template (GType type)
 {
-	if (type == TYPE_DMAPD_DMAP_DB)
-		return "dmapd-dmap-db-%s";
-	else if (type == TYPE_DB_BUILDER)
-		return "db-builder-%s";
-	else if (type == TYPE_AV_META_READER)
-		return "av-meta-reader-%s";
-	else if (type == TYPE_AV_RENDER)
-		return "av-render-%s";
-	else if (type == TYPE_PHOTO_META_READER)
-		return "photo-meta-reader-%s";
-	else
-		return NULL;
+	char *template = NULL;
+
+	if (type == TYPE_DMAPD_DMAP_DB) {
+		template = "dmapd-dmap-db-%s";
+	} else if (type == TYPE_DB_BUILDER) {
+		template = "db-builder-%s";
+	} else if (type == TYPE_AV_META_READER) {
+		template = "av-meta-reader-%s";
+	} else if (type == TYPE_AV_RENDER) {
+		template = "av-render-%s";
+	} else if (type == TYPE_PHOTO_META_READER) {
+		template = "photo-meta-reader-%s";
+	}
+
+	return template;
 }
 
 
 GObject *
-object_from_module (GType type, const gchar *module_dir, const gchar *module_name, const gchar *first_property_name, ...)
+util_object_from_module (GType type,
+                         const gchar *module_dir,
+                         const gchar *module_name,
+                         const gchar *first_property_name,
+                         ...)
 {
 	va_list ap;
 	GType *filters = NULL;
@@ -198,7 +209,7 @@ object_from_module (GType type, const gchar *module_dir, const gchar *module_nam
 
 	va_start (ap, first_property_name);
 
-	if (! (fmt = find_plugin_template (type))) {
+	if (! (fmt = _find_plugin_template (type))) {
 		g_error ("Could not find plugin template");
 	}
 
@@ -224,9 +235,7 @@ object_from_module (GType type, const gchar *module_dir, const gchar *module_nam
 			fnval = g_object_new_valist (child_type, first_property_name, ap);
 		}
 
-		if (filters)
-			g_free (filters);
-
+		g_free (filters);
 		g_free (module_filename);
 		g_free (module_path);
 	}
@@ -237,7 +246,7 @@ object_from_module (GType type, const gchar *module_dir, const gchar *module_nam
 }
 
 gboolean
-dmapd_util_hash_file (const gchar *uri, unsigned char hash[DMAP_HASH_SIZE])
+util_hash_file (const gchar *uri, unsigned char hash[DMAP_HASH_SIZE])
 {
 	g_assert (NULL != uri);
 	g_assert (NULL != hash);
@@ -290,13 +299,13 @@ _done:
 }
 
 gchar *
-cache_path (cache_type_t type, const gchar *db_dir, const gchar *uri)
+util_cache_path (cache_type_t type, const gchar *db_dir, const gchar *uri)
 {
         gchar *cachepath = NULL;
 	guchar raw_hash[DMAP_HASH_SIZE] = { 0 };
         gchar hash[DMAP_HASH_SIZE * 2 + 1] = { 0 };
 	
-	if (! dmapd_util_hash_file (uri, raw_hash)) {
+	if (! util_hash_file (uri, raw_hash)) {
 		goto _done;
 	}
 
@@ -322,7 +331,7 @@ _done:
 }
 
 void
-cache_store (const gchar *db_dir, const gchar *uri, GArray *blob)
+util_cache_store (const gchar *db_dir, const gchar *uri, GArray *blob)
 {
         struct stat st;
         gchar *cachepath = NULL;
@@ -336,7 +345,7 @@ cache_store (const gchar *db_dir, const gchar *uri, GArray *blob)
                 g_warning ("%s is not a directory, will not cache", db_dir);
 		goto _done;
         }
-        cachepath = cache_path (CACHE_TYPE_RECORD, db_dir, uri);
+        cachepath = util_cache_path (CACHE_TYPE_RECORD, db_dir, uri);
 	if (NULL == cachepath) {
 		goto _done;
 	}
